@@ -1,7 +1,7 @@
 # kate: default-dictionary en_US
 
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+## Copyright (c) 2013-2024, Marek Gagolewski <https://www.gagolewski.com/>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -69,28 +69,21 @@ stri_info <- function(short = FALSE)
     stopifnot(is.logical(short), length(short) == 1)
 
     info <- .Call(C_stri_info)
-    if (info$Charset.native$Name.friendly != "UTF-8") {
-        #       if (!info$Charset.native$CharSize.8bit)    # this should not cause problems, e.g., in the Big5 encoding
-        #          warning('You use a non-8bit native charset. ' %s+%
-        #             'This may cause serious problems. Consider switching to UTF-8.')
-        #       else
-        if (!identical(info$Charset.native$ASCII.subset, TRUE))
-            warning(stri_paste("Your native charset is not a superset of US-ASCII. ",
-                "This may cause serious problems. Consider switching to UTF-8.")) else if (!identical(info$Charset.native$Unicode.1to1, TRUE))
-            warning(stri_paste("Your native charset does not map to Unicode well. ",
-                "This may cause serious problems. Consider switching to UTF-8."))
-    }
+    #loclist <- stri_locale_list()
+    locale <- info$Locale$Name
+    charset <- info$Charset.native$Name.friendly
 
-    loclist <- stri_locale_list()
-    if (!(info$Locale$Name %in% loclist))
-        warning(stri_paste("Your current locale is not in the list of available ",
-            "locales. Some functions may not work properly. ", "Refer to stri_locale_list() for more details ",
-            "on known locale specifiers."))
+    if (charset != "UTF-8") {
+        if (!identical(info$Charset.native$ASCII.subset, TRUE))
+            warning(stri_paste("Your native character encoding is not a superset of US-ASCII. ",
+                "Consider switching to UTF-8."))
+        else if (!identical(info$Charset.native$Unicode.1to1, TRUE))
+            warning(stri_paste("Your native character encoding does not map to Unicode properly. ",
+                "Consider switching to UTF-8."))
+    }
 
     if (!short)
         return(info) else {
-        locale <- info$Locale$Name
-        charset <- info$Charset.native$Name.friendly
         return(sprintf("stringi_%s (%s.%s; ICU4C %s [%s%s]; Unicode %s)", as.character(packageVersion("stringi")),
             locale, charset, info$ICU.version, if (info$ICU.system) "system" else "bundle",
             if (info$ICU.UTF8) "#U_CHARSET_IS_UTF8" else "", info$Unicode.version))
