@@ -1,7 +1,7 @@
 # kate: default-dictionary en_US
 
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+## Copyright (c) 2013-2024, Marek Gagolewski <https://www.gagolewski.com/>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -126,8 +126,12 @@ stri_extract_first_boundaries <- function(str, ..., opts_brkiter = NULL)
 stri_extract_all_words <- function(str, simplify = FALSE, omit_no_match = FALSE,
     locale = NULL)
 {
-    stri_extract_all_boundaries(str, simplify, omit_no_match, opts_brkiter = stri_opts_brkiter(type = "word",
-        skip_word_none = TRUE, locale = locale))
+    stri_extract_all_boundaries(
+        str, simplify, omit_no_match,
+        opts_brkiter = stri_opts_brkiter(
+            type = "word", skip_word_none = TRUE, locale = locale
+        )
+    )
 }
 
 
