@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2024, Marek Gagolewski <https://www.gagolewski.com/>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -44,16 +46,15 @@
 #' and \code{stri_trim_right}.
 #'
 #' Contrary to many other string processing libraries,
-#' our trimming functions are universal. A character class,
-#' given by \code{pattern}, may be adjusted to suit your needs
-#' (yet, most often you stick to the default value).
+#' our trimming functions are universal. The class of characters
+#' to be retained or trimmed can be adjusted.
 #'
 #' For replacing pattern matches with
-#' arbitrary replacement string, see \code{\link{stri_replace}}.
+#' an arbitrary replacement string, see \code{\link{stri_replace}}.
 #'
 #' Trimming can also be used where you would normally rely on
 #' regular expressions. For instance, you may get
-#' \code{"23.5"} out of \code{"total of 23.5 bitcoins"}.
+#' \code{'23.5'} out of \code{'total of 23.5 bitcoins'}.
 #'
 #' For trimming white-spaces, please note the difference
 #' between Unicode binary property `\code{\\p\{Wspace\}}` (more universal)
@@ -61,52 +62,61 @@
 #' see \link{stringi-search-charclass}.
 #'
 #' @param str a character vector of strings to be trimmed
-#' @param pattern a single pattern, specifying character
-#' classes that should be preserved (see \link{stringi-search-charclass}).
-#'  Defaults to `\code{\\P\{Wspace\}}.
-#' @param side character [\code{stri_trim} only]; defaults to \code{"both"}
+#' @param pattern a single pattern, specifying the class of characters
+#'     (see \link{stringi-search-charclass}) to
+#'     to be preserved (if \code{negate} is \code{FALSE}; default)
+#'     or trimmed (otherwise)
+#' @param side character [\code{stri_trim} only]; defaults to \code{'both'}
+#' @param negate either \code{TRUE} or \code{FALSE}; see \code{pattern}
+#'
+#'
+#' @return
+#' All functions return a character vector.
 #'
-#' @return All these functions return a character vector.
 #'
 #' @examples
-#' stri_trim_left("               aaa")
-#' stri_trim_right("rexamine.com/", "\\p{P}")
-#' stri_trim_both(" Total of 23.5 bitcoins. ", "\\p{N}")
-#' stri_trim_both(" Total of 23.5 bitcoins. ", "\\p{L}")
+#' stri_trim_left('               aaa')
+#' stri_trim_right('r-project.org/', '\\P{P}')
+#' stri_trim_both(' Total of 23.5 bitcoins. ', '\\p{N}')
+#' stri_trim_both(' Total of 23.5 bitcoins. ', '\\P{N}', negate=TRUE)
 #'
 #' @aliases stri_trim
 #' @family search_replace
 #' @family search_charclass
 #' @rdname stri_trim
 #' @export
-stri_trim_both <- function(str, pattern="\\P{Wspace}") {
-   .Call(C_stri_trim_both, str, pattern)
+stri_trim_both <- function(str, pattern="\\P{Wspace}", negate=FALSE)
+{
+    .Call(C_stri_trim_both, str, pattern, negate)
 }
 
 
 #' @rdname stri_trim
 #' @export
-stri_trim_left <- function(str, pattern="\\P{Wspace}") {
-  .Call(C_stri_trim_left, str, pattern)
+stri_trim_left <- function(str, pattern="\\P{Wspace}", negate=FALSE)
+{
+    .Call(C_stri_trim_left, str, pattern, negate)
 }
 
 
 #' @rdname stri_trim
 #' @export
-stri_trim_right <- function(str, pattern="\\P{Wspace}") {
-  .Call(C_stri_trim_right, str, pattern)
+stri_trim_right <- function(str, pattern="\\P{Wspace}", negate=FALSE)
+{
+    .Call(C_stri_trim_right, str, pattern, negate)
 }
 
 
 #' @rdname stri_trim
 #' @export
-stri_trim <- function(str, side=c("both", "left", "right"), pattern="\\P{Wspace}") {
-   # `both` is default for compatibility with stringr
-   side <- match.arg(side) # this is slow
+stri_trim <- function(str, side=c("both", "left", "right"), pattern="\\P{Wspace}", negate=FALSE)
+{
+    # `both` is default for compatibility with stringr
+    side <- match.arg(side)  # this is slow
 
-   switch(side,
-          both  =stri_trim_both(str, pattern),
-          left  =stri_trim_left(str, pattern),
-          right =stri_trim_right(str, pattern)
-   )
+    switch(side,
+        both=stri_trim_both(str, pattern, negate),
+        left=stri_trim_left(str, pattern, negate),
+        right=stri_trim_right(str, pattern, negate)
+    )
 }
