@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2023, Marek Gagolewski <https://www.gagolewski.com/>
+ * Copyright (c) 2013-2024, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -69,8 +69,8 @@ public:
     StriContainerCharClass(SEXP rvec, R_len_t _nrecycle, bool negate=false)
     {
 #ifndef NDEBUG
-        if (!isString(rvec))
-            throw StriException("DEBUG: !isString in StriContainerCharClass::StriContainerCharClass(SEXP rvec)");
+        if (!Rf_isString(rvec))
+            throw StriException("DEBUG: !Rf_isString in StriContainerCharClass::StriContainerCharClass(SEXP rvec)");
 #endif
         int _n = LENGTH(rvec);
         this->init_Base(_n, _nrecycle, true);
