@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2024, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -58,8 +58,8 @@ public:
     {
         this->data = NULL;
 #ifndef NDEBUG
-        if (!isReal(rvec))
-            throw StriException("DEBUG: !isReal in StriContainerDouble");
+        if (!Rf_isReal(rvec))
+            throw StriException("DEBUG: !Rf_isReal in StriContainerDouble");
 #endif
         R_len_t ndata = LENGTH(rvec);
         this->init_Base(ndata, _nrecycle, true);
