@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2024, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,6 +33,8 @@
 #ifndef __stri_intvec_h
 #define __stri_intvec_h
 
+#include "stri_stringi.h"
+
 
 /**
  * A class to represent an integer vector or NULL/NA
@@ -73,11 +75,10 @@ public:
 
 
     /** constructor
-     * @param str character buffer
+     * @param data buffer
      * @param n buffer length (not including NUL)
-     * @param memalloc should a deep copy of the buffer be done?
      */
-    IntVec(const int* data, R_len_t n)
+    IntVec(const int* data, R_len_t n)  // TODO: bool memalloc
     {
         initialize(data, n);
     }
