@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2024, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -79,8 +79,8 @@ SEXP stri_detect_fixed(SEXP str, SEXP pattern, SEXP negate,
     bool negate_1 = stri__prepare_arg_logical_1_notNA(negate, "negate");
     int max_count_1 = stri__prepare_arg_integer_1_notNA(max_count, "max_count");
     uint32_t pattern_flags = StriContainerByteSearch::getByteSearchFlags(opts_fixed);
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
-    PROTECT(pattern = stri_prepare_arg_string(pattern, "pattern"));
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
+    PROTECT(pattern = stri__prepare_arg_string(pattern, "pattern"));
 
     STRI__ERROR_HANDLER_BEGIN(2)
     int vectorize_length = stri__recycling_rule(true, 2, LENGTH(str), LENGTH(pattern));
@@ -165,7 +165,7 @@ SEXP stri_detect_fixed(SEXP str, SEXP pattern, SEXP negate,
 //      uregex_reset(matcher, 0, &err);
 //      int found = (int)uregex_find(matcher, -1, &err);
 //      if (U_FAILURE(err))
-//         throw StriException(MSG__REGEXP_FAILED);
+//         throw StriException(MSG__REGEX_FAILED);
 //      LOGICAL(ret)[i] = found;
 //   }
 //
